pub struct WatchValue {
pub value: ScalarValue,
pub fingerprint: String,
}Expand description
A watch value is a value that originates from a GET.WATCH command.
Fields
value: ScalarValueThe value from the watch session, it indicates a change in a watched key.
fingerprint: StringThe fingerprint of the value, which is a unique identifier for the value.