Module errors

Module errors 

Error Module

This module contains the error types for the client and the server. The error types are used to handle errors that occur during the execution of the client and server.

Enums

ClientError
The errors that originates from the Client.
CommandError
The errors that originates from handling commands.
CommandStreamError
The errors that originates from the command stream.
StreamError
The errors that originates from base functionality of a stream, either command stream or watch stream.
WatchStreamError
The errors that originates from the watch stream.