pub enum CommandError {
ServerError(String),
DecodeError(DecodeError),
WatchValueExpectationError(String),
}Expand description
The errors that originates from handling commands.
Variants
ServerError(String)
A server side error occured. This might be caused by a bug in the SDK, or uninteded usage.
DecodeError(DecodeError)
The server returned an unexpected response, this can be caused by running on an incompatible server version.
WatchValueExpectationError(String)
The server returned an unexpected watch response, this can be caused by running on an incompatible server version.