pub enum StreamError {
IoError(Error),
DecodeError(DecodeError),
CommandError(CommandError),
}Expand description
The errors that originates from base functionality of a stream, either command stream or watch stream.
Variants
IoError(Error)
An error occured with the IO, this could be caused by the underlying IO to the server. Connection to server could be lost, or the server could have closed the connection.
DecodeError(DecodeError)
An error occured while decoding the response from the server. This can be caused by an incompatible server version.
CommandError(CommandError)
An error occured while handling a command. This can be caused by an unexpected response from the server.