pub enum WatchStreamError {
IoError(Error),
UnexpectedResponse(ScalarValue),
StreamError(StreamError),
}Expand description
The errors that originates from the watch stream.
Variants
IoError(Error)
An error occured with the IO, this could be caused by the underlying IO to the server. Connection to server could be lost, or the server could have closed the connection.
UnexpectedResponse(ScalarValue)
An error occured while decoding the response from the server. This can be caused by an incompatible server version.
StreamError(StreamError)
An error occured while handling a command.