Error Module
This module contains the error types for the client and the server. The error types are used to handle errors that occur during the execution of the client and server.
Enums
- Client
Error - The errors that originates from the Client.
- Command
Error - The errors that originates from handling commands.
- Command
Stream Error - The errors that originates from the command stream.
- Stream
Error - The errors that originates from base functionality of a stream, either command stream or watch stream.
- Watch
Stream Error - The errors that originates from the watch stream.