pub enum CommandStreamError {
ReadError(Error),
DecodeError(DecodeError),
HandshakeError(ScalarValue),
CommandError(String),
}Expand description
The errors that originates from the command stream.
Variants
ReadError(Error)
An error occured while reading from the stream. This is caused by the underlying IO to the server. Connection to server could be lost, or the server could have closed the connection.
DecodeError(DecodeError)
An error occured while decoding the response from the server. This can be caused by an incompatible server version.
HandshakeError(ScalarValue)
An unexpected value was received from the server during handshake. This can be caused by incompatible server version.
CommandError(String)
An error occured in the command stream, this can be caused by an unexpected response from the server.